@@ -74,34 +74,35 @@ class GrobidConverter(ConverterBase):
             for line in inputs:
                 line = str(line, "utf-8") if isinstance(line, bytes) else line
                 input = line.strip()
-                pdffile = None
-                try:
-                    url = urllib.parse.urlparse(input)
-                    url_path = Path(url.path)
-                    r = requests.get(
-                        input, headers={"User-Agent": "Mozilla/5.0"}, stream=True
-                    )
-                    if r.ok:
-                        with NamedTemporaryFile(
-                            suffix=".pdf", prefix=url_path.stem
-                        ) as f:
-                            for chunk in r.iter_content(chunk_size=8 * 1024):
-                                if chunk:  # filter out keep-alive new chunks
-                                    f.write(chunk)
-                            f.seek(0)
-                            doc = file_to_doc(
-                                UploadFile(f.name, f, "application/pdf"), params, client
-                            )
-                            docs.append(doc)
+                if input:
+                    pdffile = None
+                    try:
+                        url = urllib.parse.urlparse(input)
+                        url_path = Path(url.path)
+                        r = requests.get(
+                            input, headers={"User-Agent": "Mozilla/5.0"}, stream=True
+                        )
+                        if r.ok:
+                            with NamedTemporaryFile(
+                                suffix=".pdf", prefix=url_path.stem
+                            ) as f:
+                                for chunk in r.iter_content(chunk_size=8 * 1024):
+                                    if chunk:  # filter out keep-alive new chunks
+                                        f.write(chunk)
+                                f.seek(0)
+                                doc = file_to_doc(
+                                    UploadFile(f.name, f, "application/pdf"), params, client
+                                )
+                                docs.append(doc)
 
-                except BaseException:
-                    logger.warning(
-                        f"Cannot retrieve article with url {input}: ignoring",
-                        exc_info=True,
-                    )
-                finally:
-                    if pdffile:
-                        pdffile.close()
+                    except BaseException:
+                        logger.warning(
+                            f"Cannot retrieve article with url {input}: ignoring",
+                            exc_info=True,
+                        )
+                    finally:
+                        if pdffile:
+                            pdffile.close()
         else:
             try:
                 doc = file_to_doc(source, params, client)
@@ -243,7 +244,7 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
         doc.sentences = sentences
         doc.boundaries = boundaries
         if params.extract_abstract and boundaries:
-            bnames = [k for k in boundaries.keys() if k.lower() != "title"]
+            bnames = [k for k in boundaries.keys() if k is not None and k.lower() != "title"]
             if bnames:
                 abname = "ABSTRACT" if "ABSTRACT" in bnames else bnames[0]
                 ab = boundaries[abname][0]
